@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.WorkMailMessageFlow 1.17.84\n"
-        "Version:         1.17.84\n"
-        "Builder version: 4.14.0\n"
+        "Type annotations for boto3.WorkMailMessageFlow 1.17.88\n"
+        "Version:         1.17.88.post1\n"
+        "Builder version: 4.15.0\n"
         "Docs:            https://pypi.org/project/mypy-boto3-workmailmessageflow/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.84/reference/services/workmailmessageflow.html#WorkMailMessageFlow\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/workmailmessageflow.html#WorkMailMessageFlow\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.84")
+    print("1.17.88.post1")
 
 
 def main() -> None:
